#!/bin/sh
#
MMC_DEV_FILE="/dev/mmcblk0"
MNT_POINT="/var/spool/storage/SD_DISK"
INSTALL_DIR=$MNT_POINT/exacq
PKGDIR=/usr/local/packages/ExacqVision
MMC_PARTITION=$MMC_DEV_FILE"p1"

if [ ! -e $MMC_DEV_FILE ]
then
  logger -p user.err -- "ExacqVision -- ********** No CF device"
  exit
fi

if [ ! -e $MNT_POINT ] 
then
  logger -p user.err -- "ExacqVision -- ********** CF device not mounted"
  exit
fi

# do this early in the process so we don't need to flush if we have to create the installation files
mount -o remount -o exec $MNT_POINT

#  see if we need to go through the whole untar/copy/install process
NEED_UPDATE="0"

if [ ! -e $INSTALL_DIR -o ! -e $PKGDIR/core ]
then
  NEED_UPDATE="1"
fi


#  if we don't have md5 info for the install files, we better be safe
if [ ! -e $PKGDIR/oldmd5.dat ]
then
  logger -t exacqVision -- "Can't find MD5 info. Creating installation files"
  NEED_UPDATE="1"
fi

if [ "$NEED_UPDATE" -ne "0" ]
then
  logger -- "ExacqVision -- creating installation files"
  cd $PKGDIR
  mkdir -p $INSTALL_DIR
  mkdir -p $INSTALL_DIR/logs 
  mkdir -p $INSTALL_DIR/audit
  mkdir -p $INSTALL_DIR/blob
  mkdir -p $INSTALL_DIR/edvr
  mkdir -p $INSTALL_DIR/posdata
  mkdir -p $INSTALL_DIR/downloads
  mkdir -p $INSTALL_DIR/updates
  mkdir -p $INSTALL_DIR/data
  rm -rf $INSTALL_DIR/plugins
  if [ -L lib ]; then
    rm -rf lib
    mkdir lib
    mv $INSTALL_DIR/lib/libc.so lib
  fi
  rm -rf $INSTALL_DIR/lib
  rm core
  rm $INSTALL_DIR/core
  rm $INSTALL_DIR/*.xz
  rm $INSTALL_DIR/*.lzma
  rm $INSTALL_DIR/*.bz2
  rm $INSTALL_DIR/*.tar
# clean up old pre-xz install files if they exist
  rm install/*.bz2
  rm install/*.lzma
  cp install/edvrserver.tar.xz $INSTALL_DIR
  cd $INSTALL_DIR
  mv $PKGDIR/lib $PKGDIR/xz .
  ./xz -d edvrserver.tar.xz
  tar -xf edvrserver.tar
  logger -- "ExacqVision -- Done expanding tarred installation files"
  rm edvrserver.tar
  mv lib lib.tmp
  mv -f exacq/* .
  mv lib.tmp/* lib
  rm -rf lib.tmp
  cp core $PKGDIR
#
# clean up previous curl and wget
  rm -f updates/curl updates/lib* wget
#
#  Don't overwrite existing xml
#  Busybox shell cp command doesn't support -n so do it the hard way
  for fil in `ls *.xml`
  do 
    if [ ! -e $PKGDIR/$fil ]
    then
      cp $fil $PKGDIR
    fi
  done
  mv zones.txt $PKGDIR
  cd $PKGDIR
  mkdir -p edvr
  cd edvr
  ln -s $INSTALL_DIR/edvr 0
  cd ..
  ln -s $INSTALL_DIR/lib lib
  ln -s $INSTALL_DIR/plugins plugins
  ln -s $INSTALL_DIR/logs logs
  ln -s $INSTALL_DIR/audit audit
  ln -s $INSTALL_DIR/blob blob
  ln -s $INSTALL_DIR/downloads downloads
  ln -s $INSTALL_DIR/curl curl
  ln -s $INSTALL_DIR/update update
  ln -s $INSTALL_DIR/netconfig netconfig
  ln -s $INSTALL_DIR/lshw lshw
  ln -s $INSTALL_DIR/update_daemon update_daemon
  ln -s $INSTALL_DIR/data data

# remove or mv renamed copies of event DB
  for fil in `ls eventpi.db.*`
  do
      if [ -L $fil ]
      then
	  rm $fil
      else
	  mv $fil $INSTALL_DIR
      fi
  done
  echo export OLD_MD5=`md5sum $PKGDIR/install/edvrserver.tar.xz | cut -d ' ' -f1` >oldmd5.dat
  logger -- "ExacqVision -- All runtime files created"
else
  logger -- "ExacqVision -- Runtime files are already installed"
fi

cd $PKGDIR/edvr
rm -f 1 2
if [ -e /var/spool/storage/NetworkShare ]
then
    ln -s /var/spool/storage/NetworkShare 1
fi
if [ -e /var/spool/storage/SD_DISK2 ]
then
    ln -s /var/spool/storage/SD_DISK2 2
fi
cd $PKGDIR

# if pos or event database exists on flash, copy to SD & create link
if [ -e pospi.db -a ! -L pospi.db ]
then
mv pospi.db $INSTALL_DIR/posdata
elif [ -e pospi.db ]
then
rm -f pospi.db
fi
ln -s $INSTALL_DIR/posdata/pospi.db pospi.db

if [ -e eventpi.db -a ! -L eventpi.db ]
then
mv eventpi.db $INSTALL_DIR
elif [ -e eventpi.db ]
then
rm -f eventpi.db
fi
ln -s $INSTALL_DIR/eventpi.db eventpi.db

# now do the same for the wal/shm files, but don't create links
if [ -e eventpi.db-shm -a ! -L eventpi.db-shm ]
then
mv eventpi.db-shm $INSTALL_DIR
elif [ -e eventpi.db ]
then
rm -f eventpi.db-shm
fi

if [ -e eventpi.db-wal -a ! -L eventpi.db-wal ]
then
mv eventpi.db-wal $INSTALL_DIR
elif [ -e eventpi.db ]
then
rm -f eventpi.db-wal
fi

if [ -e pospi.db-shm -a ! -L pospi.db-shm ]
then
mv pospi.db-shm $INSTALL_DIR/posdata
elif [ -e pospi.db ]
then
rm -f pospi.db-shm
fi

if [ -e pospi.db-wal -a ! -L pospi.db-wal ]
then
mv pospi.db-wal $INSTALL_DIR/posdata
elif [ -e pospi.db ]
then
rm -f pospi.db-wal
fi

